==> freecad_0.19.2+dfsg1.orig.tar.xz: FreeCAD-0.19.2/src/Mod/Web/Gui/Resources/translations/Web_sv-SE.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sv-SE" sourcelanguage="en">
  <context>
    <name>CmdWebBrowserBack</name>
    <message>
      <location filename="../../Command.cpp" line="76"/>
      <source>Web</source>
      <translation>Webb</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="77"/>
      <source>Previous page</source>
      <translation>Föregående sida</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="78"/>
      <source>Go back to the previous page</source>
      <translation>Gå tillbaka till föregående sida</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserNext</name>
    <message>
      <location filename="../../Command.cpp" line="105"/>
      <source>Web</source>
      <translation>Webb</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="106"/>
      <source>Next page</source>
      <translation>Nästa sida</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="107"/>
      <source>Go to the next page</source>
      <translation>Gå till nästa sida</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserRefresh</name>
    <message>
      <location filename="../../Command.cpp" line="134"/>
      <source>Web</source>
      <translation>Webb</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="135"/>
      <location filename="../../Command.cpp" line="136"/>
      <source>Refresh web page</source>
      <translation>Uppdatera webbsida</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserSetURL</name>
    <message>
      <location filename="../../Command.cpp" line="250"/>
      <source>Web</source>
      <translation>Webb</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="251"/>
      <location filename="../../Command.cpp" line="252"/>
      <source>Set URL</source>
      <translation>Ange URL</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserStop</name>
    <message>
      <location filename="../../Command.cpp" line="162"/>
      <source>Web</source>
      <translation>Webb</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="163"/>
      <location filename="../../Command.cpp" line="164"/>
      <source>Stop loading</source>
      <translation>Avbryt hämtning</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserZoomIn</name>
    <message>
      <location filename="../../Command.cpp" line="192"/>
      <source>Web</source>
      <translation>Webb</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="193"/>
      <location filename="../../Command.cpp" line="194"/>
      <source>Zoom in</source>
      <translation>Zooma in</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserZoomOut</name>
    <message>
      <location filename="../../Command.cpp" line="221"/>
      <source>Web</source>
      <translation>Webb</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="222"/>
      <location filename="../../Command.cpp" line="223"/>
      <source>Zoom out</source>
      <translation>Zooma ut</translation>
    </message>
  </context>
  <context>
    <name>CmdWebOpenWebsite</name>
    <message>
      <location filename="../../Command.cpp" line="50"/>
      <source>Web</source>
      <translation>Webb</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="51"/>
      <source>Open website...</source>
      <translation>Öppna hemsida...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="52"/>
      <source>Opens a website in FreeCAD</source>
      <translation>Öppnar en webbplats i FreeCAD</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location filename="../../AppWebGui.cpp" line="88"/>
      <location filename="../../BrowserView.cpp" line="748"/>
      <source>Browser</source>
      <translation>Webbläsare</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="563"/>
      <source>File does not exist!</source>
      <translation>Filen existerar inte!</translation>
    </message>
  </context>
  <context>
    <name>WebGui::BrowserView</name>
    <message>
      <location filename="../../BrowserView.cpp" line="551"/>
      <location filename="../../BrowserView.cpp" line="556"/>
      <location filename="../../BrowserView.cpp" line="559"/>
      <source>Error</source>
      <translation>Fel</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="556"/>
      <source>There were errors while loading the file. Some data might have been modified or not recovered at all. Look in the report view for more specific information about the objects involved.</source>
      <translation>Det uppstod ett fel under inläsning av filen. Viss data kan ha ändrats eller inte återställts alls. Titta i rapportvyn för mer specifik information om de inblandade objekten.</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="559"/>
      <source>There were serious errors while loading the file. Some data might have been modified or not recovered at all. Saving the project will most likely result in loss of data.</source>
      <translation type="unfinished">There were serious errors while loading the file. Some data might have been modified or not recovered at all. Saving the project will most likely result in loss of data.</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="719"/>
      <source>Loading %1...</source>
      <translation>Laddar %1...</translation>
    </message>
  </context>
  <context>
    <name>WebGui::WebView</name>
    <message>
      <location filename="../../BrowserView.cpp" line="308"/>
      <source>Open in External Browser</source>
      <translation>Öppna i extern webbläsare</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="312"/>
      <source>Open in new window</source>
      <translation>Öppna i nytt fönster</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="344"/>
      <source>View source</source>
      <translation>Visa källa</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="46"/>
      <source>Navigation</source>
      <translation>Navigering</translation>
    </message>
  </context>
</TS>

==> freecad_0.20.2+dfsg1.orig.tar.xz: FreeCAD-0.20.2/src/Mod/Web/Gui/Resources/translations/Web_sv-SE.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sv-SE" sourcelanguage="en">
  <context>
    <name>CmdWebBrowserBack</name>
    <message>
      <location filename="../../Command.cpp" line="72"/>
      <source>Web</source>
      <translation>Webb</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="73"/>
      <source>Previous page</source>
      <translation>Föregående sida</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="74"/>
      <source>Go back to the previous page</source>
      <translation>Gå tillbaka till föregående sida</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserNext</name>
    <message>
      <location filename="../../Command.cpp" line="101"/>
      <source>Web</source>
      <translation>Webb</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="102"/>
      <source>Next page</source>
      <translation>Nästa sida</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="103"/>
      <source>Go to the next page</source>
      <translation>Gå till nästa sida</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserRefresh</name>
    <message>
      <location filename="../../Command.cpp" line="130"/>
      <source>Web</source>
      <translation>Webb</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="131"/>
      <location filename="../../Command.cpp" line="132"/>
      <source>Refresh web page</source>
      <translation>Uppdatera webbsida</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserSetURL</name>
    <message>
      <location filename="../../Command.cpp" line="246"/>
      <source>Web</source>
      <translation>Webb</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="247"/>
      <location filename="../../Command.cpp" line="248"/>
      <source>Set URL</source>
      <translation>Ange URL</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserStop</name>
    <message>
      <location filename="../../Command.cpp" line="158"/>
      <source>Web</source>
      <translation>Webb</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="159"/>
      <location filename="../../Command.cpp" line="160"/>
      <source>Stop loading</source>
      <translation>Avbryt hämtning</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserZoomIn</name>
    <message>
      <location filename="../../Command.cpp" line="188"/>
      <source>Web</source>
      <translation>Webb</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="189"/>
      <location filename="../../Command.cpp" line="190"/>
      <source>Zoom in</source>
      <translation>Zooma in</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserZoomOut</name>
    <message>
      <location filename="../../Command.cpp" line="217"/>
      <source>Web</source>
      <translation>Webb</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="218"/>
      <location filename="../../Command.cpp" line="219"/>
      <source>Zoom out</source>
      <translation>Zooma ut</translation>
    </message>
  </context>
  <context>
    <name>CmdWebOpenWebsite</name>
    <message>
      <location filename="../../Command.cpp" line="46"/>
      <source>Web</source>
      <translation>Webb</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="47"/>
      <source>Open website...</source>
      <translation>Öppna hemsida...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="48"/>
      <source>Opens a website in FreeCAD</source>
      <translation>Öppnar en webbplats i FreeCAD</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location filename="../../BrowserView.cpp" line="785"/>
      <location filename="../../AppWebGui.cpp" line="85"/>
      <source>Browser</source>
      <translation>Webbläsare</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="597"/>
      <source>File does not exist!</source>
      <translation>Filen existerar inte!</translation>
    </message>
  </context>
  <context>
    <name>WebGui::BrowserView</name>
    <message>
      <location filename="../../BrowserView.cpp" line="585"/>
      <location filename="../../BrowserView.cpp" line="590"/>
      <location filename="../../BrowserView.cpp" line="593"/>
      <source>Error</source>
      <translation>Fel</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="590"/>
      <source>There were errors while loading the file. Some data might have been modified or not recovered at all. Look in the report view for more specific information about the objects involved.</source>
      <translation>Det uppstod ett fel under inläsning av filen. Viss data kan ha ändrats eller inte återställts alls. Titta i rapportvyn för mer specifik information om de inblandade objekten.</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="593"/>
      <source>There were serious errors while loading the file. Some data might have been modified or not recovered at all. Saving the project will most likely result in loss of data.</source>
      <translation>Det uppstod allvarliga fel vid inläsning av filen. Vissa data kan ha ändrats eller inte återställts alls. Att spara projektet kommer sannolikt att resultera i förlust av data.</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="753"/>
      <source>Loading %1...</source>
      <translation>Laddar %1...</translation>
    </message>
  </context>
  <context>
    <name>WebGui::WebView</name>
    <message>
      <location filename="../../BrowserView.cpp" line="351"/>
      <source>Open in External Browser</source>
      <translation>Öppna i extern webbläsare</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="355"/>
      <source>Open in new window</source>
      <translation>Öppna i nytt fönster</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="387"/>
      <source>View source</source>
      <translation>Visa källa</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="37"/>
      <source>Navigation</source>
      <translation>Navigering</translation>
    </message>
  </context>
</TS>
